@@ -8,7 +8,7 @@ from typing import List, Optional
 from uuid import UUID
 
 from dateutil import parser
-from pydantic import BaseModel, ValidationError, condecimal, constr, root_validator, validator
+from pydantic import BaseModel, ConfigDict, condecimal, constr, field_validator, model_validator
 
 from ..utils.logger import payment_logger as logger
 
@@ -18,10 +18,10 @@ def check_iso_format(v):
         try:
             return parser.parse(v)  # Converte stringa in datetime
         except Exception:
-            raise ValidationError('date must be a valid ISO8601 datetime')
+            raise ValueError('date must be a valid ISO8601 datetime')
     if isinstance(v, datetime.datetime):
         return v  # Se è già un datetime, lo lascia invariato
-    raise ValidationError('expire_at must be a datetime or an ISO8601 string')
+    raise ValueError('expire_at must be a datetime or an ISO8601 string')
 
 
 def check_isoformat_none_case(v):
@@ -30,10 +30,10 @@ def check_isoformat_none_case(v):
             try:
                 return parser.parse(v)  # Converte stringa in datetime
             except Exception:
-                raise ValidationError('date must be a valid ISO8601 datetime')
+                raise ValueError('date must be a valid ISO8601 datetime')
         if isinstance(v, datetime.datetime):
             return v  # Se è già un datetime, lo lascia invariato
-        raise ValidationError('date must be a datetime or an ISO8601 string')
+        raise ValueError('date must be a datetime or an ISO8601 string')
 
 
 class HttpMethodType(Enum):
@@ -91,7 +91,7 @@ class PaymentDataSplit(BaseModel):
     amount: Optional[condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2)] = None
     meta: dict
 
-    @validator('amount', pre=True)
+    @field_validator('amount', mode='before')
     def _parse_split_amount(cls, v):
         if v in (None, ''):
             return None
@@ -112,9 +112,7 @@ class Document(BaseModel):
     ref: Optional[str]
     hash: str
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -131,9 +129,7 @@ class Receiver(BaseModel):
     country_subdivision: Optional[str]
     country: Optional[str]
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -155,14 +151,13 @@ class PaymentData(BaseModel):
     document: Optional[Document]
     split: List[Optional[PaymentDataSplit]]
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
-    paid_at_must_be_iso8601 = validator('paid_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
-    expire_at_must_be_iso8601 = validator('expire_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
+    @field_validator('paid_at', 'expire_at', mode='before')
+    def _parse_optional_datetime(cls, v):
+        return check_isoformat_none_case(v)
 
-    @validator('amount', pre=True)
+    @field_validator('amount', mode='before')
     def _parse_amount(cls, v):
         if v in (None, ''):
             return None
@@ -174,14 +169,14 @@ class PaymentData(BaseModel):
             return None
         return int((self.amount * 100).quantize(Decimal('1'), rounding=ROUND_HALF_UP))
 
-    @root_validator(pre=False)
-    def _check_splits_total(cls, values):
-        amt = values.get('amount')  # Decimal | None
-        splits = values.get('split') or []  # List[PaymentDataSplit] | []
+    @model_validator(mode='after')
+    def _check_splits_total(self):
+        amt = self.amount  # Decimal | None
+        splits = self.split or []  # List[PaymentDataSplit] | []
 
         # Se manca amount o non ci sono split, non validiamo la somma
         if amt is None or not splits:
-            return values
+            return self
 
         total = sum((s.amount for s in splits if s is not None), Decimal('0'))
 
@@ -195,22 +190,22 @@ class PaymentData(BaseModel):
         if not (total_q == amt_q or total_q == Decimal('1.00')):
             raise ValueError(f'Somma degli split {total_q} diversa da amount {amt_q}')
 
-        return values
+        return self
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
 
 
 class OnlinePaymentBegin(BaseModel):
-    url: Optional[str]
-    last_opened_at: Optional[datetime.datetime]
-    method: Optional[HttpMethodType]
+    url: Optional[str] = None
+    last_opened_at: Optional[datetime.datetime] = None
+    method: Optional[HttpMethodType] = None
 
-    last_opened_at_must_be_iso8601 = validator('last_opened_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
+    @field_validator('last_opened_at', mode='before')
+    def last_opened_at_must_be_iso8601(cls, v):
+        return check_isoformat_none_case(v)
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -241,11 +236,11 @@ class Notify(BaseModel):
     method: Optional[HttpMethodType]
     sent_at: Optional[datetime.datetime]
 
-    sent_at_must_be_iso8601 = validator('sent_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
+    @field_validator('sent_at', mode='before')
+    def sent_at_must_be_iso8601(cls, v):
+        return check_isoformat_none_case(v)
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -257,12 +252,11 @@ class Update(BaseModel):
     next_check_at: Optional[datetime.datetime]
     method: Optional[HttpMethodType]
 
-    last_check_at_must_be_iso8601 = validator('last_check_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
-    next_check_at_must_be_iso8601 = validator('next_check_at', pre=True, allow_reuse=True)(check_isoformat_none_case)
+    @field_validator('last_check_at', 'next_check_at', mode='before')
+    def _validate_check_times(cls, v):
+        return check_isoformat_none_case(v)
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -278,9 +272,7 @@ class Links(BaseModel):
     confirm: Confirm = Confirm(**{'url': None, 'last_opened_at': None, 'method': None})
     cancel: Cancel = Cancel(**{'url': None, 'last_opened_at': None, 'method': None})
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def append_notify(self, notify):
         for item in notify:
@@ -303,9 +295,7 @@ class Payer(BaseModel):
     country: Optional[str]
     email: Optional[str]
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -321,9 +311,7 @@ class Fault(BaseModel):
     type: str
     instance: Optional[str] = None
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -344,27 +332,24 @@ class Payment(BaseModel):
     links: Links
     payer: Payer
     debtor: Optional[Debtor]
-    locale: str = None
+    locale: Optional[str] = None
     event_id: UUID
     event_version: str
     event_created_at: datetime.datetime
     app_id: str
 
-    class Config:
-        validate_all = True
-        validate_assignment = True
+    model_config = ConfigDict(validate_assignment=True, validate_default=True)
 
-    created_at_must_be_iso8601 = validator('created_at', allow_reuse=True)(check_iso_format)
-    updated_at_must_be_iso8601 = validator('updated_at', allow_reuse=True)(check_iso_format)
+    @field_validator('created_at', 'updated_at', 'event_created_at')
+    def _validate_required_datetimes(cls, v):
+        return check_iso_format(v)
 
-    @validator('event_version')
+    @field_validator('event_version')
     def event_version_must_be_two(cls, v):
         if float(v) != 2.0:
-            raise ValidationError('event must have 2.0 as version')
+            raise ValueError('event must have 2.0 as version')
         return v.title()
 
-    event_created_at_must_be_iso8601 = validator('event_created_at', allow_reuse=True)(check_iso_format)
-
     def update_time(self, field):
         self._rsetattr(
             field,
@@ -438,4 +423,6 @@ class PaymentEncoder(JSONEncoder):
             return float(o.quantize(Decimal('0.01')))
         elif isinstance(o, (PaymentType, PayerType, PaymentStatus, HttpMethodType, CurrencyType)):
             return o.value
+        elif isinstance(o, BaseModel):
+            return o.model_dump()
         return o.__dict__
