@@ -2,10 +2,10 @@ import json
 from datetime import datetime, timedelta, timezone
 from decimal import Decimal
 from unittest import TestCase
+from uuid import UUID
 
 from freezegun import freeze_time
-from pydantic.error_wrappers import ValidationError
-from pydantic.types import UUID
+from pydantic import ValidationError
 
 from oc_python_sdk.models.payment import (
     CurrencyType,
